=========================
Django-comments-dab v2.8
=========================

v2.8.0
-------

Features
^^^^^^^^^

- `#244`_ - Using exists instead of count is faster.
- `#241`_ - Confirm support for django 4.0.
- `#236`_ - Confirm support for python 3.10
- `#224`_ - Move validation of orders to system checks
- `#222`_ - Add support for rendering content in markdown format.

.. _#244: https://github.com/Radi85/Comment/issues/244
.. _#241: https://github.com/Radi85/Comment/issues/241
.. _#236: https://github.com/Radi85/Comment/pull/236
.. _#224: https://github.com/Radi85/Comment/issues/224
.. _#222: https://github.com/Radi85/Comment/issues/222

Codebase enhancement
^^^^^^^^^^^^^^^^^^^^^

- `#234`_ - Add pytz as a dependency for tests.

.. _#234: https://github.com/Radi85/Comment/pull/234
